==> jc-1.4.0.tar.gz: java/util/Collections__24CopiesList.h <==
// final class java.util.Collections$CopiesList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 582805a6e4a28fbe java_util_Collections__24CopiesList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_java_util_Collections__24CopiesList_H_
#define _JC_java_util_Collections__24CopiesList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_util_Collections__24CopiesList$sub_refs	_jc_java_util_Collections__24CopiesList$sub_refs;
typedef struct _jc_java_util_Collections__24CopiesList$sub_nonrefs	_jc_java_util_Collections__24CopiesList$sub_nonrefs;
typedef struct _jc_java_util_Collections__24CopiesList$refs	_jc_java_util_Collections__24CopiesList$refs;
typedef struct _jc_java_util_Collections__24CopiesList$nonrefs	_jc_java_util_Collections__24CopiesList$nonrefs;
typedef struct _jc_java_util_Collections__24CopiesList$object	_jc_java_util_Collections__24CopiesList$object;

typedef struct _jc_java_util_Collections__24CopiesList$fields_struct	_jc_java_util_Collections__24CopiesList$fields_struct;
typedef const struct _jc_java_util_Collections__24CopiesList$vmethods	_jc_java_util_Collections__24CopiesList$vmethods;
typedef const struct _jc_java_util_Collections__24CopiesList$vtable	_jc_java_util_Collections__24CopiesList$vtable;
typedef const struct _jc_java_util_Collections__24CopiesList$vtype	_jc_java_util_Collections__24CopiesList$vtype;

// Class fields structure
struct _jc_java_util_Collections__24CopiesList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24CopiesList$fields_struct _jc_java_util_Collections__24CopiesList$class_fields;

// Constructors
extern void _jc_java_util_Collections__24CopiesList$method$_init$964b4a8e45252143(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24CopiesList$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24CopiesList$method$get$a706240e1333824b(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint);
extern jint _jc_java_util_Collections__24CopiesList$method$indexOf$59e53868af339edb(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Collections__24CopiesList$method$lastIndexOf$af030ff733adf0f9(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Collections__24CopiesList$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *);
extern struct _jc_object *_jc_java_util_Collections__24CopiesList$method$subList$af8e3c69195dae35(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint, jint);
extern _jc_object_array *_jc_java_util_Collections__24CopiesList$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_Collections__24CopiesList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$get$a706240e1333824b;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$indexOf$59e53868af339edb;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$lastIndexOf$af030ff733adf0f9;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$subList$af8e3c69195dae35;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$toArray$408321282fd84959;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_Collections__24CopiesList$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint);
	jint	(*indexOf$59e53868af339edb)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *);
	jint	(*lastIndexOf$af030ff733adf0f9)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *);
	struct _jc_object	*(*subList$af8e3c69195dae35)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint, jint);
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *);
};

// Vtable
struct _jc_java_util_Collections__24CopiesList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_Collections__24CopiesList$vmethods	java_util_Collections__24CopiesList;
};

// Vtype
struct _jc_java_util_Collections__24CopiesList$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24CopiesList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24CopiesList$sub_refs {
	struct _jc_java_lang_Object$object	*element;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24CopiesList$refs {
    _jc_java_util_Collections__24CopiesList$sub_refs	java_util_Collections__24CopiesList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24CopiesList$sub_nonrefs {
	jint	n;
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24CopiesList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_Collections__24CopiesList$sub_nonrefs	java_util_Collections__24CopiesList;
};

// Object instance structure
struct _jc_java_util_Collections__24CopiesList$object {
	_jc_java_util_Collections__24CopiesList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24CopiesList$vtype	*vtype;
	_jc_java_util_Collections__24CopiesList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24CopiesList$vtype _jc_java_util_Collections__24CopiesList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24CopiesList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24CopiesList$class_object;

#endif	/* _JC_java_util_Collections__24CopiesList_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24CopiesList.h <==
// final class java.util.Collections$CopiesList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 582805a6e4a28fbe java_util_Collections__24CopiesList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_java_util_Collections__24CopiesList_H_
#define _JC_java_util_Collections__24CopiesList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_util_Collections__24CopiesList$sub_refs	_jc_java_util_Collections__24CopiesList$sub_refs;
typedef struct _jc_java_util_Collections__24CopiesList$sub_nonrefs	_jc_java_util_Collections__24CopiesList$sub_nonrefs;
typedef struct _jc_java_util_Collections__24CopiesList$refs	_jc_java_util_Collections__24CopiesList$refs;
typedef struct _jc_java_util_Collections__24CopiesList$nonrefs	_jc_java_util_Collections__24CopiesList$nonrefs;
typedef struct _jc_java_util_Collections__24CopiesList$object	_jc_java_util_Collections__24CopiesList$object;

typedef struct _jc_java_util_Collections__24CopiesList$fields_struct	_jc_java_util_Collections__24CopiesList$fields_struct;
typedef const struct _jc_java_util_Collections__24CopiesList$vmethods	_jc_java_util_Collections__24CopiesList$vmethods;
typedef const struct _jc_java_util_Collections__24CopiesList$vtable	_jc_java_util_Collections__24CopiesList$vtable;
typedef const struct _jc_java_util_Collections__24CopiesList$vtype	_jc_java_util_Collections__24CopiesList$vtype;

// Class fields structure
struct _jc_java_util_Collections__24CopiesList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24CopiesList$fields_struct _jc_java_util_Collections__24CopiesList$class_fields;

// Constructors
extern void _jc_java_util_Collections__24CopiesList$method$_init$964b4a8e45252143(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24CopiesList$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24CopiesList$method$get$a706240e1333824b(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24CopiesList$method$indexOf$59e53868af339edb(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24CopiesList$method$lastIndexOf$af030ff733adf0f9(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24CopiesList$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24CopiesList$method$subList$af8e3c69195dae35(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint, jint) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_util_Collections__24CopiesList$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_Collections__24CopiesList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$get$a706240e1333824b;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$indexOf$59e53868af339edb;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$lastIndexOf$af030ff733adf0f9;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$subList$af8e3c69195dae35;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$toArray$408321282fd84959;
extern _jc_method _jc_java_util_Collections__24CopiesList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_Collections__24CopiesList$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint) _JC_JCNI_ATTR;
	jint	(*indexOf$59e53868af339edb)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*lastIndexOf$af030ff733adf0f9)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*subList$af8e3c69195dae35)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *, jint, jint) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_Collections__24CopiesList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24CopiesList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_Collections__24CopiesList$vmethods	java_util_Collections__24CopiesList;
};

// Vtype
struct _jc_java_util_Collections__24CopiesList$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24CopiesList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24CopiesList$sub_refs {
	struct _jc_java_lang_Object$object	*element;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24CopiesList$refs {
    _jc_java_util_Collections__24CopiesList$sub_refs	java_util_Collections__24CopiesList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24CopiesList$sub_nonrefs {
	jint	n;
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24CopiesList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_Collections__24CopiesList$sub_nonrefs	java_util_Collections__24CopiesList;
};

// Object instance structure
struct _jc_java_util_Collections__24CopiesList$object {
	_jc_java_util_Collections__24CopiesList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24CopiesList$vtype	*vtype;
	_jc_java_util_Collections__24CopiesList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24CopiesList$vtype _jc_java_util_Collections__24CopiesList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24CopiesList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24CopiesList$class_object;

#endif	/* _JC_java_util_Collections__24CopiesList_H_ */
